@@ -147,13 +147,11 @@ def save_deployment(deployment_result):
 
 
 def _deploy(project, release, environment_id, description, confirm=True):
-    environment = project.get_environment(environment_id)
-    env_id = environment.get('id')
-    env_name = environment.get('name', environment_id)
+    environment_name = project.environment_names[environment_id]
 
     click.echo("")
     click.echo(click.style(f"Deploying release {release['release_id']}", fg="green"))
-    click.echo(click.style(f"Targeting env: {env_id}, ({env_name})", fg="yellow"))
+    click.echo(click.style(f"Targeting env: {environment_id} ({environment_name})", fg="yellow"))
     click.echo(click.style(f"Requested by: {release['requested_by']}", fg="yellow"))
     click.echo(click.style(f"Date created: {release['date_created']}", fg="yellow"))
 
@@ -218,7 +216,7 @@ def _deploy(project, release, environment_id, description, confirm=True):
     click.echo(tabulate(rows, headers=headers))
 
     click.echo("")
-    click.echo(click.style(f"Deployed release {release['release_id']} to {env_id}, ({env_name})", fg="bright_green"))
+    click.echo(click.style(f"Deployed release {release['release_id']} to {environment_id} ({environment_name})", fg="bright_green"))
 
 
 @cli.command()
@@ -463,9 +461,10 @@ def show_release(ctx, release_id):
 
 @cli.command()
 @click.argument('release_id', required=False)
+@click.option('--environment-id', required=False)
 @click.option('--limit', required=False, default=10)
 @click.pass_context
-def show_deployments(ctx, release_id, limit):
+def show_deployments(ctx, release_id, environment_id, limit):
     project = ctx.obj['project']
 
     rows = []
@@ -478,7 +477,11 @@ def show_deployments(ctx, release_id, limit):
         "description"
     ]
 
-    for deployment in project.get_deployments(release_id=release_id, limit=limit):
+    for deployment in project.get_deployments(
+        release_id=release_id,
+        environment_id=environment_id,
+        limit=limit
+    ):
         rows.append(
             [
                 deployment["release_id"],
@@ -495,14 +498,11 @@ def show_deployments(ctx, release_id, limit):
 
 
 @cli.command()
-@click.option('--label', '-l', help="The label to show (e.g., latest')")
+@click.option("--label", help="The label to show", default="latest", show_default=True)
 @click.pass_context
 def show_images(ctx, label):
     project = ctx.obj['project']
 
-    if not label:
-        label = 'latest'
-
     images = project.get_images(label)
 
     rows = []
@@ -513,12 +513,9 @@ def show_images(ctx, label):
         "tag",
     ]
 
-    for image_id, ref_tags in images.items():
-        if ref_tags:
-            # It's possible to get multiple ref tags if the same image is published
-            # at different Git commits, but there are no code changes for this image
-            # between the two commits.  If so, choose one arbitrarily.
-            rows.append([image_id, label, ref_tags.pop()])
+    for image_id, ref_tag in images.items():
+        if ref_tag:
+            rows.append([image_id, label, ref_tag])
         else:
             rows.append([image_id, "-", "-"])
 
